# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/personal/herb/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/personal/herb/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Personal\\Herb\\": "packages/personal/herb/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Personal\Herb\Providers\HerbServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Herb'  => Personal\Herb\Facades\Herb::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Personal\\HerbTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Personal\Herb\Providers\HerbServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Personal\Herb\Providers\HerbServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Personal\Herb\Providers\HerbServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/herb/{modulename}

**User**

    http://path-to-route-folder/user/herb/{modulename}

**Public**

    http://path-to-route-folder/herbs


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/herb/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/herb/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/herb/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/herb/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/herb/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/herb/{modulename}/{slug}
    METHOD: GET